@@ -62,8 +62,11 @@ class Random(object):
         length = len(thelist)
         if not isinstance(thelist, list):
             thelist = list(thelist)
-        for _ in range(length * x):
-            index = self.randint(length)
-            x = thelist.pop(index)
-            thelist.append(x)
+        for _ in range(int(length * x)):
+            p = self.randint(length)
+            q = self.randint(length)
+            if p == q:
+                q += self.randint(length)
+                q %= length
+            thelist[p], thelist[q] = thelist[q], thelist[p]
         return thelist
