@@ -9,12 +9,6 @@ import bizerror
 import typing
 from decimal import Decimal
 
-try:
-    text_type = unicode
-    bytes_type = str
-except NameError:
-    text_type = str
-    bytes_type = bytes
 
 HEXLIFY_CHARS = "0123456789abcdefABCDEF"
 URLSAFEB64_CHARS = "-0123456789=ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz\r\n"
@@ -39,7 +33,7 @@ def char_force_to_int(value):
 def force_bytes(value, encoding="utf-8"):
     if value is None:
         return None
-    if isinstance(value, text_type):
+    if isinstance(value, str):
         encoding = encoding or "utf-8"
         return value.encode(encoding)
     else:
@@ -48,7 +42,7 @@ def force_bytes(value, encoding="utf-8"):
 def force_text(value, encoding=None):
     if value is None:
         return None
-    if isinstance(value, text_type):
+    if isinstance(value, str):
         return value
     if not encoding:
         encodings = default_encodings
